#!/bin/bash

. /usr/lib/tuned/functions

_JAVA_OPTIONS="-XX:+UseNUMA"
PROFILE=/etc/profile.d/java.sh

DISK_NR_REQUESTS_SAVE="${STORAGE}/disk_nr_requests${STORAGE_SUFFIX}"

set_disk_nr_requests() {
	value=$1
	shift
	rm -f "$DISK_NR_REQUESTS_SAVE"
	for disk in $@; do
		control="${disk}/queue/nr_requests"
		echo "echo $(cat $control) > $control" >> "$DISK_NR_REQUESTS_SAVE" 2>/dev/null
		(echo $value > $control) &2>/dev/null
	done
}

restore_disk_nr_requests() {
	if [ -r "$DISK_NR_REQUESTS_SAVE" ]; then
		/bin/sh "$DISK_NR_REQUESTS_SAVE" &>/dev/null
		rm -f "$DISK_NR_REQUESTS_SAVE"
	fi
}

set_jvm_use_numa(){
        if [ ! -f $PROFILE ]; then
            touch $PROFILE
        fi

        echo "export _JAVA_OPTIONS=\"$_JAVA_OPTIONS\"" > $PROFILE
}

start() {
	if ! ls /sys/block/sd* > /dev/null 2> /dev/null
	then
		return 0
	fi

	set_disk_nr_requests 512 /sys/block/sd*
	set_jvm_use_numa
}

stop() {
	restore_disk_nr_requests
	rm -rf $PROFILE
}

process $@
